Changelog
=========

v0.2.0 20210312
---------------

    - Remove unnecessary checks

v0.1.9 20210304
---------------

    - Update readme for sample configuration section

v0.1.8 20210303
---------------

    - Package some non python files

v0.1.7 20210303
---------------

    - Fix decode bug

v0.1.6 20210302
---------------

    - Upgrade dependencies
    - Remove logging
    - Add switch commit_check.enabled to control whether or not commit check is enabled
    - Fix bug: error message is not shown in Gitlab web page

v0.1.5 20210208
---------------

    - Use `sc-utilities <https://github.com/Scott-Lau/sc-utilities>`_ for logging

v0.1.4 20210201
---------------

    - Update dependency

v0.1.3 20210201
---------------

    - Using `sc-config <https://github.com/Scott-Lau/sc-config>`_ utility

v0.1.2 20210201
---------------

    - Fix a bug where cannot read default.yml configuration file
    - Add logging

v0.1.1 20210127
---------------

    - Unique source of version
    - Use `config42 <https://pypi.org/project/config42/>`_ to read configuration file
    - Support specifying configurations through file

v0.1 20210122
---------------

    - Initial version check commit
    - Add binary file check
    - Add file extensions check
    - Add file size check